# Similar Frameworks and Ideas

Generally this has quite some similarities. Including but not limited to cluster computing, visual/flow (?) based programming as well as reactive programming and more. This aims to roughly sketch and collect similar ideas in order to learn and compare!


## Very Similar
- https://timeflux.io -> awesome framework, as of yet no interaction?
- https://github.com/facebookresearch/labgraph

## Pipline Systems
- https://docs.klio.io/en/stable/
- https://mediapipe.dev

## Distributed / Cluster Computing (no state)
- https://beam.apache.org/get-started/mobile-gaming-example/
- https://spark.apache.org
- https://www.dask.org
- 

## Task / Batch Computing
- https://github.com/spotify/luigi

## Node-based Systems
- https://docs.unrealengine.com/4.26/en-US/ProgrammingAndScripting/Blueprints/UserGuide/Nodes/
- 
